"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.logger = exports.Logger = void 0;
const constants_1 = require("./constants");
const doreamon_1 = require("@zodash/doreamon");
const container_1 = require("./container");
const DEFAULT_LOGGER = doreamon_1.default.logger.getLogger('doreamonjs');
class Logger {
    constructor(options) {
        this.options = options;
        this.log = (message, ...args) => {
            this.logger.log(message, ...args);
        };
        this.info = (message, ...args) => {
            this.logger.info(message, ...args);
        };
        this.error = (message, ...args) => {
            this.logger.error(message, ...args);
        };
        this.warn = (message, ...args) => {
            this.logger.warn(message, ...args);
        };
        this.debug = (message, ...args) => {
            this.logger.debug(message, ...args);
        };
        this.getLogger = (namespace) => {
            return doreamon_1.default.logger.getLogger(namespace);
        };
    }
    get logger() {
        var _a, _b;
        if (this._logger)
            return this._logger;
        if ((_a = this.options) === null || _a === void 0 ? void 0 : _a.logger) {
            this._logger = (_b = this.options) === null || _b === void 0 ? void 0 : _b.logger;
        }
        else if (container_1.container.has(constants_1.LOGGER)) {
            this._logger = container_1.container.get(constants_1.LOGGER);
        }
        else {
            const logger = (this._logger = DEFAULT_LOGGER);
            container_1.container.register(constants_1.LOGGER, () => {
                return logger;
            });
        }
        return this._logger;
    }
}
exports.Logger = Logger;
exports.logger = new Logger();
