import type { ReactNode, CSSProperties, MouseEvent } from 'react';
export interface IMessage {
    info(content: string, duration?: number, onClose?: () => void): void | Promise<void>;
    success(content: string, duration?: number, onClose?: () => void): void | Promise<void>;
    error(content: string, duration?: number, onClose?: () => void): void | Promise<void>;
    warning(content: string, duration?: number, onClose?: () => void): void | Promise<void>;
    loading(content: string, duration?: number, onClose?: () => void): void | Promise<void>;
    open(config: OpenConfig): void | Promise<void>;
    config(options: ConfigMessageOptions): void;
}
export interface ConfigMessageOptions {
    top?: number;
    duration?: number;
    prefixCls?: string;
    getContainer?: () => HTMLElement;
    transitionName?: string;
    maxCount?: number;
    rtl?: boolean;
}
export interface OpenConfig {
    content: ReactNode;
    duration?: number;
    type: NoticeType;
    prefixCls?: string;
    rootPrefixCls?: string;
    getPopupContainer?: (triggerNode: HTMLElement) => HTMLElement;
    onClose?: () => void;
    icon?: ReactNode;
    key?: string | number;
    style?: CSSProperties;
    className?: string;
    onClick?: (e: MouseEvent<HTMLDivElement>) => void;
}
export declare type NoticeType = 'info' | 'success' | 'error' | 'warning' | 'loading';
export interface MessageConfig {
    message?: IMessage;
}
export declare class Message implements IMessage {
    private readonly options?;
    constructor(options?: MessageConfig);
    private get message();
    info(content: string, duration?: number, onClose?: () => void): void | Promise<void>;
    success(content: string, duration?: number, onClose?: () => void): void | Promise<void>;
    error(content: string, duration?: number, onClose?: () => void): void | Promise<void>;
    warning(content: string, duration?: number, onClose?: () => void): void | Promise<void>;
    loading(content: string, duration?: number, onClose?: () => void): void | Promise<void>;
    open(config: OpenConfig): void | Promise<void>;
    config(options: ConfigMessageOptions): void;
}
export declare const message: Message;
