import type { ReactNode, CSSProperties } from 'react';
export interface INotification {
    success(cfg: ArgsProps): void;
    error(cfg: ArgsProps): void;
    info(cfg: ArgsProps): void;
    warning(cfg: ArgsProps): void;
    open(cfg: ArgsProps): void;
    config(options: ConfigNotificationOptions): void;
}
export interface ArgsProps {
    message: ReactNode;
    description?: ReactNode;
    btn?: ReactNode;
    key?: string;
    onClose?: () => void;
    duration?: number | null;
    icon?: ReactNode;
    placement?: NotificationPlacement;
    style?: CSSProperties;
    prefixCls?: string;
    className?: string;
    readonly type?: IconType;
    onClick?: () => void;
    top?: number;
    bottom?: number;
    getContainer?: () => HTMLElement;
    closeIcon?: ReactNode;
}
export interface ConfigNotificationOptions {
    top?: number;
    bottom?: number;
    duration?: number;
    prefixCls?: string;
    placement?: NotificationPlacement;
    getContainer?: () => HTMLElement;
    closeIcon?: ReactNode;
    rtl?: boolean;
    maxCount?: number;
}
export declare type NotificationPlacement = 'topLeft' | 'topRight' | 'bottomLeft' | 'bottomRight';
export declare type IconType = 'success' | 'info' | 'error' | 'warning';
export interface NotificationConfig {
    notification?: INotification;
}
export declare class Notification implements INotification {
    private readonly options?;
    private _notifier;
    constructor(options?: NotificationConfig);
    private get notifier();
    success(cfg: ArgsProps): void;
    error(cfg: ArgsProps): void;
    info(cfg: ArgsProps): void;
    warning(cfg: ArgsProps): void;
    open(cfg: ArgsProps): void;
    config(options: ConfigNotificationOptions): void;
}
export declare const notification: Notification;
